;ASDesign Compatible Macro
;Name=Trees Lib: Single tree, Type=Trees \
;FixedLength=10, FixedWidth=10, Autoscale, \
;Latitude, Longitude, Range=8, Scale=1, Rotation, \
;Visibility=25000, Elevation=0, Density=2, \
;Hemisphere=0, Lat_Band=2, Tree_ID=00001
; ===================================================================
; TrSingle.scm  Trees: Single tree
; -------------------------------------------------------------------
; Author:	      Gerrish Gray, Freeware - All Rights Reserved
; Contact:      gerrish.gray@wimborne-dorset.fsnet.co.uk
; Use With:     FS2000 and ASD 2.1
; Needs:        Trees_#.bgl libraries (must be Release 2)
; ===================================================================
; NOTES:
; 1. Use Hemisphere and Latitude Band settings to select appropriate
;    seasonal behaviour corresponding to the location and altitude of
;    the scenery.  Hemisphere is 0 for Northern or 1 for Southern.
;    Latitude Band values range from 1 (tropical) to 4 (sub-arctic).
; 2. Use Tree ID to select tree type - see Trees_#.txt
;    *IMPORTANT* Not all tree types are available in all Bands. It is
;    the scenery designer's responsibility to select appropriate tree
;    types for the band in use, as detailed in the Trees_#.txt files.
;    Misuse will lead to 'Missing Object ...' error messages when 
;    opening the scenery in Flight Simulator.
; -------------------------------------------------------------------
; PARAMETERS:
; %1  = Latitude  - Tree position
; %2  = Longitude      ..   ..
; %3  = Area() range in kms
; %4  = Scale - sets size of tree
; %5  = Rotation - not used
; %6  = Visibility range in metres
; %7  = Altitude - normally leave at 0 for local ground level
; %8  = Scenery Detail level - minimum level at which tree appears
; %9  = Argument 1 - Hemisphere (0=North 1=South),
; %10 = Argument 2 - Latitude Band (1-4)
; %11 = Argument 3 - Tree ID (must be a valid ID)
; ===================================================================
; RELEASE HISTORY
; ---------------
; 2000-12-16    Release 2
;               - Uses Release 2 libraries (modified object coding
;                 & GUIDs)
;               - Adds SCM macros to SDK
; 2000-12-10    Release 1 - SCM macros not included
; *******************************************************************

; CONSTANTS
; =========

; FS2000 global variables
; -----------------------
  UVar( $detail  0x0346 ) ; scenery detail level

; Calculate ID increments from band parameters
; --------------------------------------------
mif( %9 )
  UVar( $hemi 5 )
melse
  UVar( $hemi 0 )
mifend

mif( [ abs[%10] > 4 ] )
  Error( The Latitude Band parameter must be in the range 1 to 4 )
mifend

mif( [ abs[%10] > 1 ] )
  UVar( $band abs[int[%10]] )
melse
  UVar( $band 1 )
mifend

; Tree ID's & Scales
; ------------------
  UVar( $ID1  [[0x0%11*16]+$hemi+$band] )

; BGL CODE
; ========

Area( 5 %1 %2 %3 )
  IfVarRange( : $detail %8 5 )
  PerspectiveCall( :Persp )
  Jump( : )

:Persp
  Perspective
mif( %7  )
  RefPoint( 2 :EndP %4 %1 %2 v1= %6 E= %7 V2= 50 )
melse
  RefPoint( 7 :EndP %4 %1 %2 v1= %6 V2= 50 )
mifend
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )
:EndP
  Return

EndA

