;ASDesign Compatible Macro
;Name=Trees Lib: Stand of 20 - 2 types, Type=Trees \
;FixedLength=30, FixedWidth=40, Autoscale, \
;Latitude, Longitude, Range=8, Scale=1, Rotation=0, \
;Visibility=25000, Elevation=0, Density=4, \
;Hemisphere=0, Lat_Band=2, Tree_ID_1=00001, Scale_1=1.0, \
;Tree_ID_2=00002, Scale_2=1.0
; *******************************************************************
; TrSt20_2.scm  Trees: Irregular stand of 20 trees of 2 mixed types
; -------------------------------------------------------------------
; Author:	      Gerrish Gray, Freeware - All Rights Reserved
; Contact:      gerrish.gray@wimborne-dorset.fsnet.co.uk
; Use With:     FS2000 and ASD 2.1
; Needs:        Trees_#.bgl libraries (must be Release 2)
; ===================================================================
; NOTES:
; 1. This macro creates an irregularly-shaped stand of 20 trees of
;    somewhat varying size.  Very natural in appearance.
; 2. Reference point gives position of central tree of group.  
;    Rotation parameter sets orientation.
; 3. Use Scale to set average centre-to-centre spacing (1.0 = 10m).
; 4. Use Hemisphere and Latitude Band settings to select appropriate
;    seasonal behaviour corresponding to the location and altitude of
;    the scenery.  Hemisphere is 0 for Northern or 1 for Southern.
;    Latitude Band values range from 1 (tropical) to 4 (sub-arctic).
; 5. Use Tree ID to select tree type - see Trees_#.txt
;    *IMPORTANT* Not all tree types are available in all Bands. It is
;    the scenery designer's responsibility to select appropriate tree
;    types for the band in use, as detailed in the Trees_#.txt files.
;    Misuse will lead to 'Missing Object ...' error messages when 
;    opening the scenery in Flight Simulator.
; 6. Use Tree Scale to set average tree size independently of main
;    scale.
; 7. Size of individual trees is adjusted by macro to ensure a
;    natural appearance with no two trees exactly the same size
; 8. Leave Altitude setting at zero to allow trees to stand correctly
;    on FS2000 elevated mesh terrain and follow even the steepest
;    terrain contours. (Note, however, that 3D Groups will not work
;    so well on steeper slopes).
; 9. Scenery Detail setting determines level at which ALL trees are
;    drawn. Fewer trees are drawn at lower settings, and NO trees
;    will ever be drawn when the FS2000 setting is Very Sparse
; -------------------------------------------------------------------
; PARAMETERS:
; %1  = Latitude  - Sets position of tree at centre of stand
; %2  = Longitude      ..   ..   ..
; %3  = Area() range in kms
; %4  = Scale - sets average tree spacing, 1.0 = 10m; NOT tree size
; %5  = Rotation - sets orientation - see note 2 above
; %6  = Visibility range in metres
; %7  = Altitude - normally leave at 0 for local ground level
; %8  = Scenery Detail level
; %9  = Argument 1 - Hemisphere (0=North 1=South),
; %10 = Argument 2 - Latitude Band (1-4)
; %11 = Argument 3 - Tree ID for type 1
; %12 = Argument 4 - Tree Scale for type 1
; %13 = Argument 5 - Tree ID for type 2
; %14 = Argument 6 - Tree Scale for type 2
; ===================================================================
; RELEASE HISTORY
; ---------------
; 2000-12-16    Release 2
;               - Uses Release 2 libraries (modified object coding
;                 & GUIDs)
;               - Adds SCM macros to SDK
; 2000-12-10    Release 1 - SCM macros not included
; *******************************************************************

; CONSTANTS
; =========

; FS2000 global variables
; -----------------------
  UVar( $detail  0x0346 ) ; scenery detail level

; Calculate ID increments from band parameters
; --------------------------------------------
mif( %9 )
  UVar( $hemi 5 )
melse
  UVar( $hemi 0 )
mifend

mif( [ abs[%10] > 4 ] )
  Error( The Latitude Band parameter must be in the range 1 to 4 )
mifend

mif( [ abs[%10] > 1 ] )
  UVar( $band abs[int[%10]] )
melse
  UVar( $band 1 )
mifend

; Tree ID's & Scales
; ------------------
  UVar( $ID1  [[0x0%11*16]+$hemi+$band] )
  UVar( $z1   %12 )
  UVar( $ID2  [[0x0%13*16]+$hemi+$band] )
  UVar( $z2   %14 )

; BGL CODE
; ========

Area( 5 %1 %2 %3 )
  IfVarRange( : $detail 1 5 )
  PerspectiveCall( :Persp )
  Jump( : )

; -----------------------
; TREE PATTERN:
; No tp  r   d scale det
; -- -- --- -- ----- ---
; 00  1   0  0  1.15 -3
; 11  2  30  7  1.07  0
; 12  2 100 10  0.85 -2
; 13  1 155  9  0.93  0
; 14  1 210  8  1.0  -1
; 15  2 260 11  1.07  0
; 16  2 320  8  0.93 -1
; 21  1  13 15  1.07 -3
; 22  2  40 18  1.15  0
; 23  1  68 19  0.85 -2
; 24  2  95 22  0.93  0
; 25  1 123 18  1.0  -1
; 26  1 150 17  1.07  0
; 27  2 178 15  0.93 -1
; 28  2 205 14  0.85 -3
; 29  1 233 18  1.07  0
; 2A  2 260 21  1.15 -2
; 2B  1 288 19  0.93  0
; 2C  1 315 16  1.0  -1
; 2D  2 343 14  1.07  0
; -----------------------

:Persp
  Perspective

:tree00
mif( %7  )
  RefPoint( 2 :tree11 %4 %1 %2 v1= %6 E= %7 V2= 50 )
melse
  RefPoint( 7 :tree11 %4 %1 %2 v1= %6 V2= 50 )
mifend
  SetScale( :tree11 0 0 $z1*1.15 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree11
  IfVarRange( :tree12 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree12 %4 r %5+30 7*%4 )
melse
  RefPoint( 7 :tree12 %4 r %5+30 7*%4 )
mifend
  SetScale( :tree12 0 0 $z2*1.07 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree12
  IfVarRange( :tree13 $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree13 %4 r %5+100 10*%4 )
melse
  RefPoint( 7 :tree13 %4 r %5+100 10*%4 )
mifend
  SetScale( :tree13 0 0 $z2*0.85 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree13
  IfVarRange( :tree14 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree14 %4 r %5+155 9*%4 )
melse
  RefPoint( 7 :tree14 %4 r %5+155 9*%4 )
mifend
  SetScale( :tree14 0 0 $z1*0.93 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree14
  IfVarRange( :tree15 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree15 %4 r %5+210 8*%4 )
melse
  RefPoint( 7 :tree15 %4 r %5+210 8*%4 )
mifend
  SetScale( :tree15 0 0 $z1 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree15
  IfVarRange( :tree16 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree16 %4 r %5+260 11*%4 )
melse
  RefPoint( 7 :tree16 %4 r %5+260 11*%4 )
mifend
  SetScale( :tree16 0 0 $z2*1.07 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree16
  IfVarRange( :tree21 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree21 %4 r %5+320 8*%4 )
melse
  RefPoint( 7 :tree21 %4 r %5+320 8*%4 )
mifend
  SetScale( :tree21 0 0 $z2*0.93 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree21
mif( %7  )
  RefPoint( 2 :tree22 %4 r %5+13 15*%4 )
melse
  RefPoint( 7 :tree22 %4 r %5+13 15*%4 )
mifend
  SetScale( :tree22 0 0 $z1*1.07 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree22
  IfVarRange( :tree23 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree23 %4 r %5+40 18*%4 )
melse
  RefPoint( 7 :tree23 %4 r %5+40 18*%4 )
mifend
  SetScale( :tree23 0 0 $z2*1.15 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree23
  IfVarRange( :tree24 $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree24 %4 r %5+68 19*%4 )
melse
  RefPoint( 7 :tree24 %4 r %5+68 19*%4 )
mifend
  SetScale( :tree24 0 0 $z1*0.85 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree24
  IfVarRange( :tree25 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree25 %4 r %5+95 22*%4 )
melse
  RefPoint( 7 :tree25 %4 r %5+95 22*%4 )
mifend
  SetScale( :tree25 0 0 $z2*0.93 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree25
  IfVarRange( :tree26 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree26 %4 r %5+123 18*%4 )
melse
  RefPoint( 7 :tree26 %4 r %5+123 18*%4 )
mifend
  SetScale( :tree26 0 0 $z1 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree26
  IfVarRange( :tree27 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree27 %4 r %5+150 17*%4 )
melse
  RefPoint( 7 :tree27 %4 r %5+150 17*%4 )
mifend
  SetScale( :tree27 0 0 $z1*1.07 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree27
  IfVarRange( :tree28 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree28 %4 r %5+178 15*%4 )
melse
  RefPoint( 7 :tree28 %4 r %5+178 15*%4 )
mifend
  SetScale( :tree28 0 0 $z2*0.93 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree28
mif( %7  )
  RefPoint( 2 :tree29 %4 r %5+205 14*%4 )
melse
  RefPoint( 7 :tree29 %4 r %5+205 14*%4 )
mifend
  SetScale( :tree29 0 0 $z2*0.85 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree29
  IfVarRange( :tree2A $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree2A %4 r %5+233 18*%4 )
melse
  RefPoint( 7 :tree2A %4 r %5+233 18*%4 )
mifend
  SetScale( :tree2A 0 0 $z1*1.07 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree2A
  IfVarRange( :tree2B $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree2B %4 r %5+260 21*%4 )
melse
  RefPoint( 7 :tree2B %4 r %5+260 21*%4 )
mifend
  SetScale( :tree2B 0 0 $z2*1.15 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree2B
  IfVarRange( :tree2C $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree2C %4 r %5+288 19*%4 )
melse
  RefPoint( 7 :tree2C %4 r %5+288 19*%4 )
mifend
  SetScale( :tree2C 0 0 $z1*0.93 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree2C
  IfVarRange( :tree2D $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree2D %4 r %5+315 16*%4 )
melse
  RefPoint( 7 :tree2D %4 r %5+315 16*%4 )
mifend
  SetScale( :tree2D 0 0 $z1 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree2D
  IfVarRange( :EndP $detail %8 5 )
mif( %7  )
  RefPoint( 2 :EndP %4 r %5+343 14*%4 )
melse
  RefPoint( 7 :EndP %4 r %5+343 14*%4 )
mifend
  SetScale( :EndP 0 0 $z2*1.07 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:EndP
  Return
EndA

